@@ -1,9 +1,13 @@
-import sys, os, curses, subprocess
+import sys
+import os
+import curses
+import subprocess
 import kaa
 from kaa.command import Commands, command, is_enable, norec, norerun
 
 
 class ToolCommands(Commands):
+
     @command('python.console')
     @norerun
     def pythonconsole(self, wnd):
@@ -49,7 +53,7 @@ class ToolCommands(Commands):
         def callback(w, s):
             s = s.strip()
             if s:
-                kaa.app.config.hist_shellcommands.add(s)
+                kaa.app.config.hist('shellcommand').add(s)
                 ret = subprocess.check_output(
                     s, stderr=subprocess.STDOUT,
                     shell=True,
@@ -57,25 +61,30 @@ class ToolCommands(Commands):
 
                 wnd.document.mode.edit_commands.put_string(wnd, ret)
                 wnd.screen.selection.clear()
-                
+
                 kaa.app.messagebar.set_message(
                     "{} letters inserted".format(len(ret)))
 
-        hist = [s for s, info in kaa.app.config.hist_shellcommands.get()]
+        hist = [s for s, info in kaa.app.config.hist('shellcommand').get()]
         from kaa.ui.inputline import inputlinemode
-        doc = inputlinemode.InputlineMode.build('Shell command:', 
-                    callback, history=hist)
+        doc = inputlinemode.InputlineMode.build('Shell command:',
+                                                callback, history=hist)
         kaa.app.messagebar.set_message('Execute shell command')
 
         kaa.app.show_dialog(doc)
 
     def _exec_cmd(self, cmd):
         # todo: move to util
-        import select, errno
+        import select
+        import errno
+        # http://stackoverflow.com/a/12207447
+        # This page sujests bare os pipes is never buffered.
+        # Is it true? Looks works fine, though.
         master, slave = os.pipe()
-        with subprocess.Popen(cmd, shell=True, stdout=slave, 
-                stderr=slave, bufsize=1,
-                universal_newlines=True) as process:
+        # todo: Make these handles not inherited in Python 3.3.
+        with subprocess.Popen(cmd, shell=True, stdout=slave,
+                              stderr=slave, bufsize=1,
+                              universal_newlines=True) as process:
 
             os.close(slave)
 
@@ -90,7 +99,7 @@ class ToolCommands(Commands):
                         print(l, end='')
             finally:
                 output.close()
-                
+
             retcode = process.poll()
             if retcode:
                 code = errno.errorcode.get(retcode)
@@ -98,21 +107,21 @@ class ToolCommands(Commands):
                     code = '(%s):' % code
                 else:
                     code = ''
-                
+
                 msg = os.strerror(retcode)
                 kaa.app.messagebar.set_message(
                     '{code}{msg}'.format(
                         code=code, msg=msg, retcode=retcode))
 
             return ''.join(lines)
-            
+
     @command('tools.make')
     @norerun
     def execute_make(self, wnd):
         def callback(w, s):
             s = s.strip()
             if s:
-                kaa.app.config.hist_makecommands.add(s)
+                kaa.app.config.hist('makecommand').add(s)
                 # todo: move these lines to kaa.cui.*
                 curses.def_prog_mode()
                 curses.endwin()
@@ -126,11 +135,10 @@ class ToolCommands(Commands):
                 makeoutputmode.show(s, ret)
 
         from kaa.ui.inputline import inputlinemode
-        hist = [s for s, info in kaa.app.config.hist_makecommands.get()]
+        hist = [s for s, info in kaa.app.config.hist('makecommand').get()]
         value = 'make' if not hist else hist[0]
         doc = inputlinemode.InputlineMode.build('Make command:', callback,
-                history=hist, value=value)
+                                                history=hist, value=value)
         kaa.app.messagebar.set_message('Execute command')
 
         kaa.app.show_dialog(doc)
-
