@@ -1,3 +1,4 @@
+import time
 import socket
 import pickle
 import sys
@@ -11,12 +12,13 @@ from kaa.ui.messagebar import messagebarmode
 
 from kaa.exceptions import KaaError
 
+
 class CuiApp:
     SHOW_MENU_MESSAGE = 'Type F1 or alt+/ for menu.'
     DEFAULT_THEME = 'basic'
     DEFAULT_PALETTE = 'dark'
     MAX_CLIPBOARD = 10
-    
+
     def __init__(self, config):
         self.config = config
         self.colors = None
@@ -28,15 +30,16 @@ class CuiApp:
         self.theme = self.DEFAULT_THEME
         self.last_dir = '.'
         self._input_readers = []
+        self._tasks = []
         
     def init(self, mainframe):
         if self.config.palette:
             self.set_palette(self.config.palette)
         elif not self.colors:
             self.set_palette(self.DEFAULT_PALETTE)
-            
+
         self.config.init_history()
-        
+
         self.messagebar = messagebarmode.MessageBarMode()
 
         buf = document.Buffer()
@@ -53,7 +56,7 @@ class CuiApp:
 
     def on_shutdown(self):
         self.config.close()
-        
+
     def get_current_theme(self):
         return self.theme
 
@@ -66,21 +69,40 @@ class CuiApp:
             return color.LightPalette()
         else:
             return color.DarkPalette()
-            
+
     def quit(self):
         self._quit = True
 
+    def call_later(self, secs, f):
+       self._tasks.append((time.time()+secs, f))
+
+    SCHEDULE_WAIT_MARGIN = 0.05
+    def _next_sheduled_task(self):
+        tasks = sorted(t for t, f in self._tasks)
+        if tasks:
+            wait = max(0, tasks[0] - time.time())
+            return wait + wait*self.SCHEDULE_WAIT_MARGIN
+        else:
+            None
+
+    def _run_scheduled_task(self):
+        now = time.time()
+        for n, (t, f) in enumerate(self._tasks):
+            if t <= now:
+                del self._tasks[n]
+                f()
+                return
+        
     def set_idlejob(self):
         self._idleprocs = [
             doc.mode.on_idle for doc in document.Document.all if doc.mode]
-
+        
     def on_idle(self):
         if self._idleprocs:
             proc = self._idleprocs.pop(0)
             # proc() returns True if proc() still has job to be done.
             if proc():
                 self._idleprocs.append(proc)
-                return True
 
         if self._idleprocs:
             return True
@@ -113,7 +135,7 @@ class CuiApp:
         try:
             if not isinstance(key, int):
                 key = ord(key)
-                
+
             return str(curses.keyname(key), 'utf-8', 'replace')
         except Exception:
             return '?'
@@ -139,9 +161,9 @@ class CuiApp:
                 if not (0x40 <= ord(c) <= 0x5f):
                     raise KaaError(
                         'Cannot use control key for character: {!r}'.format((mod, c)))
-                return meta+chr(ord(c)-0x40)
+                return meta + chr(ord(c) - 0x40)
             else:
-                return meta+c
+                return meta + c
         else:
             ret = keydef.keyfromname(c, ctrl, shift)
             if ret is None:
@@ -167,7 +189,7 @@ class CuiApp:
         '''
         ret = self.mainframe.show_doc(doc)
         return ret
-        
+
     def show_inputline(self, doc):
         self._idleprocs = None  # Reschedule idle procs
         dlg = dialog.DialogWnd(parent=self.mainframe, doc=doc)
@@ -194,24 +216,23 @@ class CuiApp:
 
     def get_clipboard(self):
         return self._clipboard[0] if self._clipboard else ''
-        
+
     def get_clipboards(self):
         return iter(self._clipboard)
-        
+
     def set_clipboard(self, s):
         self._clipboard.insert(0, s)
         del self._clipboard[self.MAX_CLIPBOARD:]
 
-
     def add_input_reader(self, reader):
         self._input_readers.append(reader)
 
     def del_input_reader(self, reader):
         if reader in self._input_readers:
             self._input_readers.remove(reader)
-        
+
     def run(self):
-        
+
         nonblocking = True
         while not self._quit:
             try:
@@ -230,19 +251,24 @@ class CuiApp:
 
                 try:
                     rlist, _, _ = select.select(
-                            [sys.stdin]+rd, [], [], 
-                            0 if nonblocking else None)
+                        [sys.stdin] + rd, [], [],
+                        0 if nonblocking else self._next_sheduled_task())
 
                 except InterruptedError:
                     pass
 
-                else:
-                    ready = [r for r in rlist if r is not sys.stdin]
-                    if ready:
-                        nonblocking = True
-                        for r in ready:
-                            idx = rd.index(r)
-                            self._input_readers[idx].read_input(r)
+                if not nonblocking and not rlist:
+                    # timeout
+                    self._run_scheduled_task()
+                    self.set_idlejob()  # Reschedule idle procs
+                    
+                ready = [r for r in rlist if r is not sys.stdin]
+                if ready:
+                    nonblocking = True
+                    for r in ready:
+                        idx = rd.index(r)
+                        self._input_readers[idx].read_input(r)
+                    self.set_idlejob()  # Reschedule idle procs
 
                 inputs = self.focus.do_input(nonblocking=True)
                 for c in inputs:
@@ -266,10 +292,9 @@ class CuiApp:
                         nonblocking = False
                 else:
                     self.set_idlejob()  # Reschedule idle procs
-                    
+
             except Exception as e:
                 kaa.log.error('Unhandled exception', exc_info=True)
                 kaa.app.messagebar.set_message(str(e))
 
                 nonblocking = True
-
