@@ -1,4 +1,5 @@
-import sys, traceback
+import sys
+import traceback
 from contextlib import contextmanager
 import kaa
 from kaa import document
@@ -15,12 +16,13 @@ pythonconsole_keys = {
 
 PythonConsoleThemes = {
     'basic':
-        Theme([
-            Style('stdout', 'Default', 'Default'),
-            Style('stderr', 'Magenta', 'Default'),
-        ]),
+    Theme([
+        Style('stdout', 'Default', 'Default'),
+        Style('stderr', 'Magenta', 'Default'),
+    ]),
 }
 
+
 class PythonConsoleMode(pythonmode.PythonMode):
     MODENAME = 'Python console'
     DOCUMENT_MODE = False
@@ -41,20 +43,21 @@ class PythonConsoleMode(pythonmode.PythonMode):
         output = self.output
         style_stdout = output.mode.get_styleid('stdout')
         style_stderr = output.mode.get_styleid('stderr')
-        
+
         class out:
+
             def __init__(self, style):
                 self.style = style
-                
+
             def write(self, s):
                 if not output.closed:
                     output.append(s, self.style)
-                
+
         sys.stdout = out(style_stdout)
         sys.stderr = out(style_stderr)
 
         yield
-        
+
         sys.stdout = stdout
         sys.stderr = stderr
 
@@ -64,10 +67,9 @@ class PythonConsoleMode(pythonmode.PythonMode):
             w.screen.locate(w.screen.pos, top=True)
             w.cursor.eof()
 
-
     def _eval_str(self, s):
         try:
-            comp = compile(s,  '<interactive input>','eval')
+            comp = compile(s, '<interactive input>', 'eval')
         except SyntaxError:
             return
 
@@ -84,7 +86,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
 
     def _exec_str(self, s):
         try:
-            comp = compile(s,  '<interactive input>','exec')
+            comp = compile(s, '<interactive input>', 'exec')
         except SyntaxError:
             traceback.print_exc()
             return
@@ -108,12 +110,12 @@ class PythonConsoleMode(pythonmode.PythonMode):
             s = wnd.document.gettext(f, t)
         else:
             s = wnd.document.gettext(0, wnd.document.endpos())
-        
+
         s = s.rstrip()
         if not s:
             return
 
-        scr = s+'\n'
+        scr = s + '\n'
 
         with self._redirect_output():
             if not self._eval_str(s):
@@ -121,11 +123,12 @@ class PythonConsoleMode(pythonmode.PythonMode):
 
         if not is_sel:
             endpos = self.document.endpos()
-            if not self.document.gettext(endpos-1, endpos).endswith('\n'):
+            if not self.document.gettext(endpos - 1, endpos).endswith('\n'):
                 self.edit_commands.insert_string(wnd, self.document.endpos(),
-                    '\n', update_cursor=False)
+                                                 '\n', update_cursor=False)
             wnd.screen.selection.set_range(0, endpos)
-            
+
+
 class PythonOutputMode(defaultmode.DefaultMode):
     MODENAME = 'Python outputs'
     DOCUMENT_MODE = False
