@@ -7,15 +7,17 @@ from kaa.theme import Theme, Style
 
 import kaa_testutils
 
+
 class TestDialogCursor(kaa_testutils._TestScreenBase):
+
     def _getcursor(self, s):
         wnd = self._getwnd(s)
         return dialogmode.DialogCursor(wnd, [dialogmode.MarkRange('mark1'), dialogmode.MarkRange('mark2')])
 
     def test_cursorrange(self):
         cursor = self._getcursor("0123456789")
-        cursor.wnd.document.marks['mark1'] = (1,3)
-        cursor.wnd.document.marks['mark2'] = (5,10)
+        cursor.wnd.document.marks['mark1'] = (1, 3)
+        cursor.wnd.document.marks['mark2'] = (5, 10)
 
         cursor.setpos(1)
         cursor.left()
@@ -36,6 +38,7 @@ class TestDialogCursor(kaa_testutils._TestScreenBase):
 
 
 class TestFormBuilder(kaa_testutils._TestScreenBase):
+
     def _getmodeclass(self):
         return dialogmode.DialogMode
 
@@ -46,7 +49,7 @@ class TestFormBuilder(kaa_testutils._TestScreenBase):
         f.append_text('default', 'abc')
 
         assert doc.gettext(0, doc.endpos()) == 'abc'
-        assert doc.styles.getints(0, doc.endpos()) == [0]*doc.endpos()
+        assert doc.styles.getints(0, doc.endpos()) == [0] * doc.endpos()
 
     def test_build_mark(self):
         doc = self._getdoc('')
@@ -63,14 +66,16 @@ class TestFormBuilder(kaa_testutils._TestScreenBase):
 
             doc = self._getdoc('')
 
-            doc.mode.themes = [{'basic':Theme([
+            doc.mode.themes = [{'basic': Theme([
                 Style('default', 'default', 'default', False, False),
                 Style('shortcut', 'default', 'default', False, False),
             ])}]
             doc.mode._build_theme()
 
             f = dialogmode.FormBuilder(doc)
-            def cb(wnd):pass
+
+            def cb(wnd):
+                pass
             f.append_text('default', 'ab&cdef', on_shortcut=cb,
                           shortcut_style='shortcut', shortcut_mark='mark1')
 
@@ -78,6 +83,6 @@ class TestFormBuilder(kaa_testutils._TestScreenBase):
 
         id1 = doc.mode.get_styleid('default')
         id2 = doc.mode.get_styleid('shortcut')
-        assert doc.styles.getints(0, doc.endpos()) == [id1, id1, id2, id1, id1, id1]
+        assert doc.styles.getints(
+            0, doc.endpos()) == [id1, id1, id2, id1, id1, id1]
         assert doc.marks['mark1'] == 2
-
